@@ -1,23 +1,26 @@
-#' Add Correlates of War trade data to a dyad-year or state-year data frame
+#' Add Correlates of War trade data to a data frame
 #'
-#' @description \code{add_cow_trade()} allows you to add Correlates of War alliance
-#' data to a dyad-year data frame
+#' @description \code{add_cow_trade()} allows you to add Correlates of War trade data to your
+#' (dyad-year, leader-year, leader-dyad-year, state-year) data frame
 #'
-#' @return \code{add_cow_trade()} takes a dyad-year data frame or state-year data frame and
-#' adds information about the volume of trade in that given dyad-year or state-year. For the state-year
-#' data, these are minimally the sum of all imports and the sum of all exports. For dyad-year data,
+#' @return \code{add_cow_trade()} takes a (dyad-year, leader-year, leader-dyad-year, state-year) data frame and
+#' adds information about the volume of trade in that given dyad-year or state-year. For the state-year (leader-year)
+#' data, these are minimally the sum of all imports and the sum of all exports. For dyad-year (leader-dyad-year) data,
 #' this function returns the value of imports in current million USD in the first country from
 #' the second country (and vice-versa) along with their "smooth" equivalents.
 #'
-#' @details For the dyad-year data, there must be some kind of information loss in order to work within the
+#' @details For the dyad-year (and leader-dyad-year) data, there must be some kind of information loss in order to work within the
 #' limited space available to this package. This package loads a truncated version of the data in which the trade
-#' values are rounded to integers in order to greatly reduce the disk space for this package. I do not think this
+#' values are rounded to three decimal points in order to greatly reduce the disk space for this package. I do not think this
 #' to be terribly problematic, though I admit I do not like it. If this is a problem for your research question,
-#' you may want to consider not using this function for dyad-year data.
+#' you may want to consider not using this function for dyad-year or leader-dyad-year data.
+#'
+#' Be mindful that the data are fundamentally state-year or dyad-year and that extensions to leader-level data should be understood
+#' as approximations for leaders (leader-dyads) in a given state-year (dyad-year).
 #'
 #' @author Steven V. Miller
 #'
-#' @param data a dyad-year data frame (either "directed" or "non-directed") or a state-year data frame
+#' @param data a data frame with appropriate \pkg{peacesciencer} attributes
 #'
 #' @references
 #'
@@ -34,7 +37,7 @@
 
 add_cow_trade <- function(data) {
 
-  if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "dyad_year") {
+  if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type %in% c("dyad_year", "leader_dyad_year")) {
 
     if (!all(i <- c("ccode1", "ccode2") %in% colnames(data))) {
 
@@ -45,7 +48,7 @@ add_cow_trade <- function(data) {
 
       if (!file.exists(system.file("extdata", "cow_trade_ddy.rds", package="peacesciencer"))) {
 
-        stop("Dyadic CoW trade data is now stored remotely and must be downloaded separately.\nThis error disappears after successfully running `download_extdata()`. Thereafter, the function works with no problem and the dyadic trade data (`cow_trade_ddy`) can be loaded for additional exploration.")
+        stop("Dyadic CoW trade data are now stored remotely and must be downloaded separately.\nThis error disappears after successfully running `download_extdata()`. Thereafter, the function works with no problem and the dyadic trade data (`cow_trade_ddy`) can be loaded for additional exploration.")
 
       } else {
 
@@ -58,7 +61,7 @@ add_cow_trade <- function(data) {
 
     }
 
-  } else if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "state_year") {
+  } else if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type %in% c("state_year", "leader_year")) {
 
     if (!all(i <- c("ccode") %in% colnames(data))) {
 
